@@ -84,70 +84,70 @@ DebuggerMainWnd::DebuggerMainWnd(const char* name) :
     initKAction();
     initToolbar(); // kind of obsolete?
 
-    connect(m_watches, SIGNAL(addWatch()), SLOT(slotAddWatch()));
-    connect(m_watches, SIGNAL(deleteWatch()), m_debugger, SLOT(slotDeleteWatch()));
-    connect(m_watches, SIGNAL(textDropped(const TQString&)), SLOT(slotAddWatch(const TQString&)));
+    connect(m_watches, TQ_SIGNAL(addWatch()), TQ_SLOT(slotAddWatch()));
+    connect(m_watches, TQ_SIGNAL(deleteWatch()), m_debugger, TQ_SLOT(slotDeleteWatch()));
+    connect(m_watches, TQ_SIGNAL(textDropped(const TQString&)), TQ_SLOT(slotAddWatch(const TQString&)));
 
-    connect(&m_filesWindow->m_findDlg, SIGNAL(closed()), SLOT(updateUI()));
-    connect(m_filesWindow, SIGNAL(newFileLoaded()),
-	    SLOT(slotNewFileLoaded()));
-    connect(m_filesWindow, SIGNAL(toggleBreak(const TQString&,int,const DbgAddr&,bool)),
-	    this, SLOT(slotToggleBreak(const TQString&,int,const DbgAddr&,bool)));
-    connect(m_filesWindow, SIGNAL(enadisBreak(const TQString&,int,const DbgAddr&)),
-	    this, SLOT(slotEnaDisBreak(const TQString&,int,const DbgAddr&)));
-    connect(m_debugger, SIGNAL(activateFileLine(const TQString&,int,const DbgAddr&)),
-	    m_filesWindow, SLOT(activate(const TQString&,int,const DbgAddr&)));
-    connect(m_debugger, SIGNAL(executableUpdated()),
-	    m_filesWindow, SLOT(reloadAllFiles()));
-    connect(m_debugger, SIGNAL(updatePC(const TQString&,int,const DbgAddr&,int)),
-	    m_filesWindow, SLOT(updatePC(const TQString&,int,const DbgAddr&,int)));
+    connect(&m_filesWindow->m_findDlg, TQ_SIGNAL(closed()), TQ_SLOT(updateUI()));
+    connect(m_filesWindow, TQ_SIGNAL(newFileLoaded()),
+	    TQ_SLOT(slotNewFileLoaded()));
+    connect(m_filesWindow, TQ_SIGNAL(toggleBreak(const TQString&,int,const DbgAddr&,bool)),
+	    this, TQ_SLOT(slotToggleBreak(const TQString&,int,const DbgAddr&,bool)));
+    connect(m_filesWindow, TQ_SIGNAL(enadisBreak(const TQString&,int,const DbgAddr&)),
+	    this, TQ_SLOT(slotEnaDisBreak(const TQString&,int,const DbgAddr&)));
+    connect(m_debugger, TQ_SIGNAL(activateFileLine(const TQString&,int,const DbgAddr&)),
+	    m_filesWindow, TQ_SLOT(activate(const TQString&,int,const DbgAddr&)));
+    connect(m_debugger, TQ_SIGNAL(executableUpdated()),
+	    m_filesWindow, TQ_SLOT(reloadAllFiles()));
+    connect(m_debugger, TQ_SIGNAL(updatePC(const TQString&,int,const DbgAddr&,int)),
+	    m_filesWindow, TQ_SLOT(updatePC(const TQString&,int,const DbgAddr&,int)));
     // value popup communication
-    connect(m_filesWindow, SIGNAL(initiateValuePopup(const TQString&)),
-	    m_debugger, SLOT(slotValuePopup(const TQString&)));
-    connect(m_debugger, SIGNAL(valuePopup(const TQString&)),
-	    m_filesWindow, SLOT(slotShowValueTip(const TQString&)));
+    connect(m_filesWindow, TQ_SIGNAL(initiateValuePopup(const TQString&)),
+	    m_debugger, TQ_SLOT(slotValuePopup(const TQString&)));
+    connect(m_debugger, TQ_SIGNAL(valuePopup(const TQString&)),
+	    m_filesWindow, TQ_SLOT(slotShowValueTip(const TQString&)));
     // disassembling
-    connect(m_filesWindow, SIGNAL(disassemble(const TQString&, int)),
-	    m_debugger, SLOT(slotDisassemble(const TQString&, int)));
-    connect(m_debugger, SIGNAL(disassembled(const TQString&,int,const std::list<DisassembledCode>&)),
-	    m_filesWindow, SLOT(slotDisassembled(const TQString&,int,const std::list<DisassembledCode>&)));
-    connect(m_filesWindow, SIGNAL(moveProgramCounter(const TQString&,int,const DbgAddr&)),
-	    m_debugger, SLOT(setProgramCounter(const TQString&,int,const DbgAddr&)));
+    connect(m_filesWindow, TQ_SIGNAL(disassemble(const TQString&, int)),
+	    m_debugger, TQ_SLOT(slotDisassemble(const TQString&, int)));
+    connect(m_debugger, TQ_SIGNAL(disassembled(const TQString&,int,const std::list<DisassembledCode>&)),
+	    m_filesWindow, TQ_SLOT(slotDisassembled(const TQString&,int,const std::list<DisassembledCode>&)));
+    connect(m_filesWindow, TQ_SIGNAL(moveProgramCounter(const TQString&,int,const DbgAddr&)),
+	    m_debugger, TQ_SLOT(setProgramCounter(const TQString&,int,const DbgAddr&)));
     // program stopped
-    connect(m_debugger, SIGNAL(programStopped()), SLOT(slotProgramStopped()));
-    connect(&m_backTimer, SIGNAL(timeout()), SLOT(slotBackTimer()));
+    connect(m_debugger, TQ_SIGNAL(programStopped()), TQ_SLOT(slotProgramStopped()));
+    connect(&m_backTimer, TQ_SIGNAL(timeout()), TQ_SLOT(slotBackTimer()));
     // tab width
-    connect(this, SIGNAL(setTabWidth(int)), m_filesWindow, SIGNAL(setTabWidth(int)));
+    connect(this, TQ_SIGNAL(setTabWidth(int)), m_filesWindow, TQ_SIGNAL(setTabWidth(int)));
 
     // connect breakpoint table
-    connect(m_bpTable, SIGNAL(activateFileLine(const TQString&,int,const DbgAddr&)),
-	    m_filesWindow, SLOT(activate(const TQString&,int,const DbgAddr&)));
-    connect(m_debugger, SIGNAL(updateUI()), m_bpTable, SLOT(updateUI()));
-    connect(m_debugger, SIGNAL(breakpointsChanged()), m_bpTable, SLOT(updateBreakList()));
-    connect(m_debugger, SIGNAL(breakpointsChanged()), m_bpTable, SLOT(updateUI()));
+    connect(m_bpTable, TQ_SIGNAL(activateFileLine(const TQString&,int,const DbgAddr&)),
+	    m_filesWindow, TQ_SLOT(activate(const TQString&,int,const DbgAddr&)));
+    connect(m_debugger, TQ_SIGNAL(updateUI()), m_bpTable, TQ_SLOT(updateUI()));
+    connect(m_debugger, TQ_SIGNAL(breakpointsChanged()), m_bpTable, TQ_SLOT(updateBreakList()));
+    connect(m_debugger, TQ_SIGNAL(breakpointsChanged()), m_bpTable, TQ_SLOT(updateUI()));
 
-    connect(m_debugger, SIGNAL(registersChanged(const std::list<RegisterInfo>&)),
-	    m_registers, SLOT(updateRegisters(const std::list<RegisterInfo>&)));
+    connect(m_debugger, TQ_SIGNAL(registersChanged(const std::list<RegisterInfo>&)),
+	    m_registers, TQ_SLOT(updateRegisters(const std::list<RegisterInfo>&)));
 
-    connect(m_debugger, SIGNAL(memoryDumpChanged(const TQString&, const std::list<MemoryDump>&)),
-	    m_memoryWindow, SLOT(slotNewMemoryDump(const TQString&, const std::list<MemoryDump>&)));
-    connect(m_debugger, SIGNAL(saveProgramSpecific(TDEConfigBase*)),
-	    m_memoryWindow, SLOT(saveProgramSpecific(TDEConfigBase*)));
-    connect(m_debugger, SIGNAL(restoreProgramSpecific(TDEConfigBase*)),
-	    m_memoryWindow, SLOT(restoreProgramSpecific(TDEConfigBase*)));
+    connect(m_debugger, TQ_SIGNAL(memoryDumpChanged(const TQString&, const std::list<MemoryDump>&)),
+	    m_memoryWindow, TQ_SLOT(slotNewMemoryDump(const TQString&, const std::list<MemoryDump>&)));
+    connect(m_debugger, TQ_SIGNAL(saveProgramSpecific(TDEConfigBase*)),
+	    m_memoryWindow, TQ_SLOT(saveProgramSpecific(TDEConfigBase*)));
+    connect(m_debugger, TQ_SIGNAL(restoreProgramSpecific(TDEConfigBase*)),
+	    m_memoryWindow, TQ_SLOT(restoreProgramSpecific(TDEConfigBase*)));
 
     // thread window
-    connect(m_debugger, SIGNAL(threadsChanged(const std::list<ThreadInfo>&)),
-	    m_threads, SLOT(updateThreads(const std::list<ThreadInfo>&)));
-    connect(m_threads, SIGNAL(setThread(int)),
-	    m_debugger, SLOT(setThread(int)));
+    connect(m_debugger, TQ_SIGNAL(threadsChanged(const std::list<ThreadInfo>&)),
+	    m_threads, TQ_SLOT(updateThreads(const std::list<ThreadInfo>&)));
+    connect(m_threads, TQ_SIGNAL(setThread(int)),
+	    m_debugger, TQ_SLOT(setThread(int)));
 
     // view menu changes when docking state changes
-    connect(dockManager, SIGNAL(change()), SLOT(updateUI()));
+    connect(dockManager, TQ_SIGNAL(change()), TQ_SLOT(updateUI()));
 
     // popup menu of the local variables window
-    connect(m_localVariables, SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)),
-	    this, SLOT(slotLocalsPopup(TQListViewItem*, const TQPoint&)));
+    connect(m_localVariables, TQ_SIGNAL(contextMenuRequested(TQListViewItem*, const TQPoint&, int)),
+	    this, TQ_SLOT(slotLocalsPopup(TQListViewItem*, const TQPoint&)));
 
     restoreSettings(kapp->config());
 
@@ -176,39 +176,39 @@ DebuggerMainWnd::~DebuggerMainWnd()
 void DebuggerMainWnd::initKAction()
 {
     // file menu
-    TDEAction* open = KStdAction::open(this, SLOT(slotFileOpen()), 
+    TDEAction* open = KStdAction::open(this, TQ_SLOT(slotFileOpen()), 
                       actionCollection());
     open->setText(i18n("&Open Source..."));
-    KStdAction::close(m_filesWindow, SLOT(slotClose()), actionCollection());
+    KStdAction::close(m_filesWindow, TQ_SLOT(slotClose()), actionCollection());
     (void)new TDEAction(i18n("&Reload Source"), "reload", 0, m_filesWindow, 
-                      SLOT(slotFileReload()), actionCollection(), 
+                      TQ_SLOT(slotFileReload()), actionCollection(), 
                       "file_reload");
     (void)new TDEAction(i18n("&Executable..."), "execopen", 0, this, 
-                      SLOT(slotFileExe()), actionCollection(), 
+                      TQ_SLOT(slotFileExe()), actionCollection(), 
                       "file_executable");
     m_recentExecAction = new TDERecentFilesAction(i18n("Recent E&xecutables"), 0,
-		      this, SLOT(slotRecentExec(const KURL&)),
+		      this, TQ_SLOT(slotRecentExec(const KURL&)),
 		      actionCollection(), "file_executable_recent");
-    (void)new TDEAction(i18n("&Core dump..."), 0, this, SLOT(slotFileCore()),
+    (void)new TDEAction(i18n("&Core dump..."), 0, this, TQ_SLOT(slotFileCore()),
                       actionCollection(), "file_core_dump");
-    KStdAction::quit(kapp, SLOT(closeAllWindows()), actionCollection());
+    KStdAction::quit(kapp, TQ_SLOT(closeAllWindows()), actionCollection());
 
     // settings menu
     (void)new TDEAction(i18n("This &Program..."), 0, this,
-		      SLOT(slotFileProgSettings()), actionCollection(),
+		      TQ_SLOT(slotFileProgSettings()), actionCollection(),
 		      "settings_program");
     (void)new TDEAction(i18n("&Global Options..."), 0, this, 
-                      SLOT(slotFileGlobalSettings()), actionCollection(),
+                      TQ_SLOT(slotFileGlobalSettings()), actionCollection(),
                       "settings_global");
-    KStdAction::keyBindings(this, SLOT(slotConfigureKeys()), actionCollection());
-    KStdAction::showStatusbar(this, SLOT(slotViewStatusbar()), actionCollection());
+    KStdAction::keyBindings(this, TQ_SLOT(slotConfigureKeys()), actionCollection());
+    KStdAction::showStatusbar(this, TQ_SLOT(slotViewStatusbar()), actionCollection());
 
     // view menu
     (void)new TDEToggleAction(i18n("&Find"), "edit-find", CTRL+Key_F, m_filesWindow,
-			    SLOT(slotViewFind()), actionCollection(),
+			    TQ_SLOT(slotViewFind()), actionCollection(),
 			    "view_find");
-    (void)KStdAction::findNext(m_filesWindow, SLOT(slotFindForward()), actionCollection(), "view_findnext");
-    (void)KStdAction::findPrev(m_filesWindow, SLOT(slotFindBackward()), actionCollection(), "view_findprev");
+    (void)KStdAction::findNext(m_filesWindow, TQ_SLOT(slotFindForward()), actionCollection(), "view_findnext");
+    (void)KStdAction::findPrev(m_filesWindow, TQ_SLOT(slotFindBackward()), actionCollection(), "view_findprev");
 
     i18n("Source &code");
     struct { TQString text; TQWidget* w; TQString id; } dw[] = {
@@ -223,82 +223,82 @@ void DebuggerMainWnd::initKAction()
     };
     for (unsigned i = 0; i < sizeof(dw)/sizeof(dw[0]); i++) {
 	KDockWidget* d = dockParent(dw[i].w);
-	(void)new TDEToggleAction(dw[i].text, 0, d, SLOT(changeHideShowState()),
+	(void)new TDEToggleAction(dw[i].text, 0, d, TQ_SLOT(changeHideShowState()),
 			  actionCollection(), dw[i].id.latin1());
     }
 
     
     // execution menu
     TDEAction* a = new TDEAction(i18n("&Run"), "pgmrun", Key_F5, m_debugger, 
-		      SLOT(programRun()), actionCollection(), "exec_run");
-    connect(a, SIGNAL(activated()), this, SLOT(intoBackground()));
+		      TQ_SLOT(programRun()), actionCollection(), "exec_run");
+    connect(a, TQ_SIGNAL(activated()), this, TQ_SLOT(intoBackground()));
     a = new TDEAction(i18n("Step &into"), "pgmstep", Key_F8, m_debugger, 
-                      SLOT(programStep()), actionCollection(), 
+                      TQ_SLOT(programStep()), actionCollection(), 
                       "exec_step_into");
-    connect(a, SIGNAL(activated()), this, SLOT(intoBackground()));
+    connect(a, TQ_SIGNAL(activated()), this, TQ_SLOT(intoBackground()));
     a = new TDEAction(i18n("Step &over"), "pgmnext", Key_F10, m_debugger, 
-                      SLOT(programNext()), actionCollection(), 
+                      TQ_SLOT(programNext()), actionCollection(), 
                       "exec_step_over");
-    connect(a, SIGNAL(activated()), this, SLOT(intoBackground()));
+    connect(a, TQ_SIGNAL(activated()), this, TQ_SLOT(intoBackground()));
     a = new TDEAction(i18n("Step o&ut"), "pgmfinish", Key_F6, m_debugger,
-                      SLOT(programFinish()), actionCollection(), 
+                      TQ_SLOT(programFinish()), actionCollection(), 
                       "exec_step_out");
-    connect(a, SIGNAL(activated()), this, SLOT(intoBackground()));
+    connect(a, TQ_SIGNAL(activated()), this, TQ_SLOT(intoBackground()));
     a = new TDEAction(i18n("Run to &cursor"), Key_F7, this,
-                      SLOT(slotExecUntil()), actionCollection(), 
+                      TQ_SLOT(slotExecUntil()), actionCollection(), 
                       "exec_run_to_cursor");
-    connect(a, SIGNAL(activated()), this, SLOT(intoBackground()));
+    connect(a, TQ_SIGNAL(activated()), this, TQ_SLOT(intoBackground()));
     a = new TDEAction(i18n("Step i&nto by instruction"), "pgmstepi", 
-		      SHIFT+Key_F8, m_debugger, SLOT(programStepi()), 
+		      SHIFT+Key_F8, m_debugger, TQ_SLOT(programStepi()), 
 		      actionCollection(), "exec_step_into_by_insn");
-    connect(a, SIGNAL(activated()), this, SLOT(intoBackground()));
+    connect(a, TQ_SIGNAL(activated()), this, TQ_SLOT(intoBackground()));
     a = new TDEAction(i18n("Step o&ver by instruction"), "pgmnexti", 
-		      SHIFT+Key_F10, m_debugger, SLOT(programNexti()), 
+		      SHIFT+Key_F10, m_debugger, TQ_SLOT(programNexti()), 
 		      actionCollection(), "exec_step_over_by_insn");
-    connect(a, SIGNAL(activated()), this, SLOT(intoBackground()));
+    connect(a, TQ_SIGNAL(activated()), this, TQ_SLOT(intoBackground()));
     (void)new TDEAction(i18n("&Program counter to current line"), 0,
-		      m_filesWindow, SLOT(slotMoveProgramCounter()),
+		      m_filesWindow, TQ_SLOT(slotMoveProgramCounter()),
 		      actionCollection(), "exec_movepc");
     (void)new TDEAction(i18n("&Break"), 0, m_debugger,
-                      SLOT(programBreak()), actionCollection(),
+                      TQ_SLOT(programBreak()), actionCollection(),
                       "exec_break");
     (void)new TDEAction(i18n("&Kill"), 0, m_debugger,
-                      SLOT(programKill()), actionCollection(),
+                      TQ_SLOT(programKill()), actionCollection(),
                       "exec_kill");
     (void)new TDEAction(i18n("Re&start"), 0, m_debugger,
-                      SLOT(programRunAgain()), actionCollection(),
+                      TQ_SLOT(programRunAgain()), actionCollection(),
                       "exec_restart");
     (void)new TDEAction(i18n("A&ttach..."), 0, this,
-                      SLOT(slotExecAttach()), actionCollection(),
+                      TQ_SLOT(slotExecAttach()), actionCollection(),
                       "exec_attach");
     (void)new TDEAction(i18n("&Arguments..."), 0, this,
-                      SLOT(slotExecArgs()), actionCollection(),
+                      TQ_SLOT(slotExecArgs()), actionCollection(),
                       "exec_arguments");
    
     // breakpoint menu
     (void)new TDEAction(i18n("Set/Clear &breakpoint"), "brkpt", Key_F9,
-                      m_filesWindow, SLOT(slotBrkptSet()), actionCollection(),
+                      m_filesWindow, TQ_SLOT(slotBrkptSet()), actionCollection(),
                       "breakpoint_set");
     (void)new TDEAction(i18n("Set &temporary breakpoint"), SHIFT+Key_F9,
-                      m_filesWindow, SLOT(slotBrkptSetTemp()), actionCollection(),
+                      m_filesWindow, TQ_SLOT(slotBrkptSetTemp()), actionCollection(),
                       "breakpoint_set_temporary");
     (void)new TDEAction(i18n("&Enable/Disable breakpoint"), CTRL+Key_F9,
-                      m_filesWindow, SLOT(slotBrkptEnable()), actionCollection(),
+                      m_filesWindow, TQ_SLOT(slotBrkptEnable()), actionCollection(),
                       "breakpoint_enable");
    
     // only in popup menus
     (void)new TDEAction(i18n("Watch Expression"), 0, this,
-                      SLOT(slotLocalsToWatch()), actionCollection(),
+                      TQ_SLOT(slotLocalsToWatch()), actionCollection(),
                       "watch_expression");
     (void)new TDEAction(i18n("Edit Value"), Key_F2, this,
-		      SLOT(slotEditValue()), actionCollection(),
+		      TQ_SLOT(slotEditValue()), actionCollection(),
 		      "edit_value");
 
     // all actions force an UI update
     TQValueList<TDEAction*> actions = actionCollection()->actions();
     TQValueList<TDEAction*>::Iterator it = actions.begin();
     for (; it != actions.end(); ++it) {
-	connect(*it, SIGNAL(activated()), this, SLOT(updateUI()));
+	connect(*it, TQ_SIGNAL(activated()), this, TQ_SLOT(updateUI()));
     }
 
     createGUI("kdbgui.rc");
@@ -308,7 +308,7 @@ void DebuggerMainWnd::initToolbar()
 {
     TDEToolBar* toolbar = toolBar("mainToolBar");
     toolbar->insertAnimatedWidget(ID_STATUS_BUSY,
-	actionCollection()->action("exec_break"), SLOT(activate()),
+	actionCollection()->action("exec_break"), TQ_SLOT(activate()),
 	"pulse", -1);
     toolbar->alignItemRight(ID_STATUS_BUSY, true);
     m_animRunning = false;
@@ -656,8 +656,8 @@ TQString DebuggerMainWnd::createOutputWindow()
 {
     TQString tty = DebuggerMainWndBase::createOutputWindow();
     if (!tty.isEmpty()) {
-	connect(m_outputTermProc, SIGNAL(processExited(TDEProcess*)),
-		SLOT(slotTermEmuExited()));
+	connect(m_outputTermProc, TQ_SIGNAL(processExited(TDEProcess*)),
+		TQ_SLOT(slotTermEmuExited()));
     }
     return tty;
 }
