@@ -26,7 +26,7 @@ protected:
 
 class OutputSettings : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     OutputSettings(TQWidget* parent);
     void setTTYLevel(int l);
@@ -41,7 +41,7 @@ protected slots:
 
 class ProgramSettings : public TQTabDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     ProgramSettings(TQWidget* parent, TQString exeName, bool modal = true);
 
