@@ -16,7 +16,7 @@ class ThreadEntry;
 
 class ThreadList : public TQListView
 {
-    Q_OBJECT
+    TQ_OBJECT
 public:
     ThreadList(TQWidget* parent, const char* name);
     ~ThreadList();
